@@ -1,16 +1,19 @@
-from typing import Callable, Optional
+from typing import Dict, List, Optional, Union
 
+from ..events import Handler, ValueChangeEventArguments
+from .mixins.disableable_element import DisableableElement
 from .mixins.value_element import ValueElement
 
 
-class Date(ValueElement):
-    EVENT_ARGS = None
+class Date(ValueElement, DisableableElement):
 
     def __init__(self,
-                 value: Optional[str] = None,
+                 value: Optional[
+                     Union[str, Dict[str, str], List[str], List[Union[str, Dict[str, str]]]]
+                 ] = None,
                  *,
                  mask: str = 'YYYY-MM-DD',
-                 on_change: Optional[Callable] = None) -> None:
+                 on_change: Optional[Handler[ValueChangeEventArguments]] = None) -> None:
         """Date Input
 
         This element is based on Quasar's `QDate <https://quasar.dev/vue-components/date>`_ component.
