@@ -1,9 +1,6 @@
-from typing import Optional
+from typing import Literal, Optional
 
-from typing_extensions import Literal
-
-from ..colors import set_text_color
-from ..element import Element
+from .mixins.color_elements import TextColorElement
 
 SpinnerTypes = Literal[
     'default',
@@ -32,24 +29,23 @@ SpinnerTypes = Literal[
 ]
 
 
-class Spinner(Element):
+class Spinner(TextColorElement):
 
     def __init__(self,
-                 type: Optional[SpinnerTypes] = 'default', *,
+                 type: Optional[SpinnerTypes] = 'default', *,  # pylint: disable=redefined-builtin
                  size: str = '1em',
                  color: Optional[str] = 'primary',
                  thickness: float = 5.0,
                  ) -> None:
         """Spinner
 
-        See `Quasar Spinner <https://quasar.dev/vue-components/spinners>`_ for more information.
+        This element is based on Quasar's `QSpinner <https://quasar.dev/vue-components/spinners>`_ component.
 
         :param type: type of spinner (e.g. "audio", "ball", "bars", ..., default: "default")
         :param size: size of the spinner (e.g. "3em", "10px", "xl", ..., default: "1em")
         :param color: color of the spinner (either a Quasar, Tailwind, or CSS color or `None`, default: "primary")
         :param thickness: thickness of the spinner (applies to the "default" spinner only, default: 5.0)
         """
-        super().__init__('q-spinner' if type == 'default' else f'q-spinner-{type}')
+        super().__init__(tag='q-spinner' if type == 'default' else f'q-spinner-{type}', text_color=color)
         self._props['size'] = size
-        set_text_color(self, color)
         self._props['thickness'] = thickness
