@@ -1,5 +1,6 @@
-from typing_extensions import Literal
+from typing import Literal
 
 Appearance = Literal[
     'none',
+    'auto',
 ]
