@@ -1,18 +1,24 @@
-from typing_extensions import Literal
+from typing import Literal
 
 BackdropOpacity = Literal[
     '0',
     '5',
     '10',
+    '15',
     '20',
     '25',
     '30',
+    '35',
     '40',
+    '45',
     '50',
+    '55',
     '60',
+    '65',
     '70',
     '75',
     '80',
+    '85',
     '90',
     '95',
     '100',
