@@ -1,6 +1,8 @@
-from typing_extensions import Literal
+from typing import Literal
 
 Floats = Literal[
+    'start',
+    'end',
     'right',
     'left',
     'none',
