@@ -1,4 +1,4 @@
-from typing_extensions import Literal
+from typing import Literal
 
 GridRowStartEnd = Literal[
     'auto',
@@ -8,6 +8,12 @@ GridRowStartEnd = Literal[
     'span-4',
     'span-5',
     'span-6',
+    'span-7',
+    'span-8',
+    'span-9',
+    'span-10',
+    'span-11',
+    'span-12',
     'span-full',
     'start-1',
     'start-2',
@@ -16,6 +22,12 @@ GridRowStartEnd = Literal[
     'start-5',
     'start-6',
     'start-7',
+    'start-8',
+    'start-9',
+    'start-10',
+    'start-11',
+    'start-12',
+    'start-13',
     'start-auto',
     'end-1',
     'end-2',
@@ -24,5 +36,11 @@ GridRowStartEnd = Literal[
     'end-5',
     'end-6',
     'end-7',
+    'end-8',
+    'end-9',
+    'end-10',
+    'end-11',
+    'end-12',
+    'end-13',
     'end-auto',
 ]
