@@ -1,4 +1,4 @@
-from typing_extensions import Literal
+from typing import Literal
 
 GridTemplateColumns = Literal[
     '1',
@@ -14,4 +14,5 @@ GridTemplateColumns = Literal[
     '11',
     '12',
     'none',
+    'subgrid',
 ]
