@@ -1,4 +1,4 @@
-from typing_extensions import Literal
+from typing import Literal
 
 GridTemplateRows = Literal[
     '1',
@@ -7,5 +7,12 @@ GridTemplateRows = Literal[
     '4',
     '5',
     '6',
+    '7',
+    '8',
+    '9',
+    '10',
+    '11',
+    '12',
     'none',
+    'subgrid',
 ]
