@@ -1,4 +1,4 @@
-from typing_extensions import Literal
+from typing import Literal
 
 Height = Literal[
     '0',
@@ -54,6 +54,9 @@ Height = Literal[
     '5/6',
     'full',
     'screen',
+    'svh',
+    'lvh',
+    'dvh',
     'min',
     'max',
     'fit',
