@@ -1,4 +1,4 @@
-from typing_extensions import Literal
+from typing import Literal
 
 MaxHeight = Literal[
     '0',
@@ -39,6 +39,9 @@ MaxHeight = Literal[
     'none',
     'full',
     'screen',
+    'svh',
+    'lvh',
+    'dvh',
     'min',
     'max',
     'fit',
