@@ -1,4 +1,4 @@
-from typing_extensions import Literal
+from typing import Literal
 
 MixBlendMode = Literal[
     'normal',
@@ -17,5 +17,6 @@ MixBlendMode = Literal[
     'saturation',
     'color',
     'luminosity',
+    'plus-darker',
     'plus-lighter',
 ]
