@@ -1,4 +1,4 @@
-from typing_extensions import Literal
+from typing import Literal
 
 Width = Literal[
     '0',
@@ -65,6 +65,9 @@ Width = Literal[
     '11/12',
     'full',
     'screen',
+    'svw',
+    'lvw',
+    'dvw',
     'min',
     'max',
     'fit',
